@@ -80,7 +80,7 @@ def init_mail(app):
 class Message(object):
 
     def __init__(self, subject, 
-                 recipients=[], 
+                 recipients=None, 
                  body=None, 
                  html=None, 
                  sender=None):
@@ -93,6 +93,9 @@ class Message(object):
         self.body = body
         self.html = html
 
+        if recipients is None:
+            recipients = []
+
         self.recipients = recipients
         
         self.attachments = []
